@@ -1,4 +1,24 @@
+# The MIT License (MIT)
+#
 # Copyright (c) 2014 JohnyMoSwag <johnymoswag@gmail.com>
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
+
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
 
 from getpass import getpass
 import hashlib
@@ -14,9 +34,9 @@ class SetupConfig(object):
     # If left None "Not_So_TUF" will be used
     APP_NAME = None
 
-    # Directory for updater to downlaod and
-    # verify files.  If left blank will be place
-    # in the users home directory Unix ".Not_So_TUF"
+    # Directory for updater to place verified updates.
+    # If left blank will be place in the users home
+    # directory Unix ".Not_So_TUF"
     # windows "Not_So_Tuf"
     APP_DATA_DIR = None
 
@@ -55,14 +75,14 @@ class SetupConfig(object):
 
     # Upload Setup
     REMOTE_DIR = None
+    HOST = None
+
     # SSH settings
     # Path to ssh key of server
-    SSH_HOST = None
     SSH_USERNAME = None
     SSH_KEY_PATH = ''
 
     # FTP settings
-    FTP_HOST = None
     FTP_USERNAME = None
     FTP_PASSWORD = None
 
@@ -78,27 +98,15 @@ class SetupConfig(object):
         self.PUBLIC_KEY_NAME = name + '.pub'
 
 
-def get_correct_answer(question, default=None, required=False,
-                       password=False, create_account=False):
+def get_correct_answer(question, default=None, required=False):
     while 1:
         if default is None:
-            msg = ''
+            msg = 'None'
         else:
-            msg = '\n[DEFAULT] -> {}\nPress Enter To Use Default'.format(default)
+            msg = ('\n[DEFAULT] -> {}\nPress Enter To '
+                   'Use Default'.format(default))
         prompt = question + msg + '\n--> '
-        if password:
-            log.debug('Not echoing pass to console')
-            answer = getpass(prompt)
-            if not create_account:
-                return answer
-            print '\n\n'
-            answer1 = getpass('Again ' + prompt)
-            if answer == answer1:
-                return answer
-            print 'Passwords didn\'t match\n'
-            continue
-        else:
-            answer = raw_input(prompt)
+        answer = raw_input(prompt)
         if answer == '' and required:
             print 'You have to enter a value\n\n'
             raw_input('Press enter to continue')
@@ -163,3 +171,16 @@ def _directory_fixer(_dir):
         _dir = _dir[2:]
         _dir = os.path.join(os.path.expanduser('~'), _dir)
     return _dir
+
+
+# Used to prevent sending out updates with debug
+# turned on...
+# If there is a better way to do this please chime in!
+def dev_machine_check():
+    files = os.listdir(os.getcwd())
+    if 'app.py' in files and 'make_binary.py' in files:
+        log.debug('We are on the dev machine.')
+        return logging.DEBUG
+    else:
+        log.debug('I am not on the dev machine.')
+        return logging.INFO
