@@ -1,11 +1,36 @@
+# The MIT License (MIT)
+#
 # Copyright (c) 2014 JohnyMoSwag <johnymoswag@gmail.com>
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
+
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
 
 from ftplib import FTP_TLS
 import logging
 import os
 import sys
+import time
+
+from . import UploaderError
+from .utils import _remove_hidden_stuff_mac, ChDir
 
 try:
+    from boto.exception import S3ResponseError
     from boto.s3.connection import S3Connection
     from boto.s3.key import Key
 except ImportError:
@@ -14,9 +39,6 @@ except ImportError:
 from paramiko import SSHClient
 from scp import SCPClient
 
-from . import UploaderError
-from .utils import _remove_hidden_stuff_mac, ChDir
-
 log = logging.getLogger(__name__)
 
 
@@ -59,12 +81,8 @@ class Uploader(object):
         self.access_key = obj.config.get('ACCESS_KEY_ID', None)
         self.secret_key = obj.config.get('SECRET_ACCESS_KEY', None)
         self.bucket_name = obj.config.get('BUCKET_NAME', None)
-
-        self.uploader = self._get_uploader()
-        if self.uploader is None:
-            self.ready = False
-        else:
-            self.ready = True
+        self.ready = False
+        self.uplaoder = None
 
     def upload(self):
         """Proxy function that calls the upload method on the received uploader
@@ -74,31 +92,62 @@ class Uploader(object):
             self.uploader.deploy_dir = self.deploy_dir
             self.uploader.upload()
 
-    def _get_uploader(self):
-        """Uses set config options to return an uploader.  In the following
-        order.  SSH, S3, SFTP.  S3 and SFTP uploaders not supported at this
-        time.
-        """
-        files = _remove_hidden_stuff_mac(os.listdir(self.deploy_dir))
-        if self.host is not None and self.ssh_username is not None:
-            return SSHUploader(file_list=files, remote_dir=self.remote_dir,
-                               host=self.host, username=self.ssh_username,
-                               ssh_key_file=self.ssh_key_path)
+    def set_uploader(self, requested_uploader):
+        """Returns an uploader object. 1 of S3, SCP, SFTP.
+        SFTP uploaders not supported at this time.
 
+        Args:
+            requested_uploader (string): Either s3 or scp
+
+        Returns:
+            object (instance): Uploader object
+        """
+        log.debug('Requested uploader type: {}'.format(
+                  type(requested_uploader)))
+
+        if isinstance(requested_uploader, str):
+            requested_uploader = requested_uploader.lower()
+        else:
+            raise UploaderError('You must provide a string to set_uploader',
+                                expected=True)
+
+        files = _remove_hidden_stuff_mac(os.listdir(self.deploy_dir))
+        if 's3' in requested_uploader and len(requested_uploader) == 2:
+            if self.access_key is None and self.secret_key is not None \
+                    and self.bucket_name is not None:
+                    self.ready = True
+                    self.uploader = S3Uploader(file_list=files,
+                                               aws_access_id=self.access_key,
+                                               aws_secret_key=self.secret_key,
+                                               bucket_name=self.bucket_name)
+            else:
+                log.error('You must provide all correct s3 settings')
+
+        elif 'scp' in requested_uploader and len(requested_uploader) == 3:
+            if self.host is not None and self.ssh_username is not None:
+                self.uplaoder = True
+                self.uploader = SSHUploader(file_list=files,
+                                            remote_dir=self.remote_dir,
+                                            host=self.host,
+                                            username=self.ssh_username,
+                                            ssh_key_file=self.ssh_key_path)
+            else:
+                log.error('You must provide all correct scp settings.')
+        else:
+            log.error('You must provide a valid option. Either s3 or scp')
+
+        return
+        # ToDo: Add stp to elif statement once implemented!
         if self.host is not None and self.ftp_username is not None:
             if self.ftp_password is not None:
                 pass
             else:
-                raise UploaderError(u'You must provide ftp password')
-
-        if self.access_key is not None and self.secret_key is not None:
-            if self.bucket_name is not None:
-                pass
-            else:
-                raise UploaderError(u'You must provide bucket name',
+                raise UploaderError(u'You must provide ftp password',
                                     expected=True)
+
         if getattr(sys, 'frozen', False):
-            return None
+            raise UploaderError(u'Make sure you have all config options set',
+                                expected=True)
         raise UploaderError(u'Make sure you have all config options set',
                             expected=True)
 
@@ -148,11 +197,10 @@ class BaseUploader(object):
         self.files_completed = 1
         self.file_count = self._get_filelist_count()
         for f in self.file_list:
-            msg = '\rUploading: {}' .format(f)
-            msg2 = ' - File {} of {}'.format(self.files_completed,
-                                             self.file_count)
-            sys.stdout.write(msg + msg2)
-            sys.stdout.flush()
+            msg = 'Uploading: {}' .format(f)
+            msg2 = ' - File {} of {}\n'.format(self.files_completed,
+                                               self.file_count)
+            print msg + msg2
             complete = self._upload_file(f)
             if complete:
                 log.debug('{} uploaded successfully'.format(f))
@@ -164,6 +212,7 @@ class BaseUploader(object):
             self._retry_upload()
         if len(self.failed_uploads) < 1:
             print "\nUpload Complete"
+            time.sleep(3)
         else:
             print 'The following files were not uploaded'
             for i in self.failed_uploads:
@@ -177,17 +226,23 @@ class BaseUploader(object):
         failed_count = len(retry)
         count = 1
         for f in retry:
-            msg = '\rRetyring: {} - File {} of {}'.format(f,
+            msg = 'Retyring: {} - File {} of {}\n'.format(f,
                                                           count,
                                                           failed_count)
-            sys.stdout.write(msg)
-            sys.stdout.flush()
+            print msg
             complete = self._upload_file(f)
             if complete:
                 log.debug('{} uploaded on retry'.format(f))
                 count += 1
             else:
                 self.failed_uploads.append(f)
+        if len(self.failed_uploads) > 0:
+            print '\nThe following files failed to upload...'
+            for f in self.failed_uploads:
+                print f
+            time.sleep(3)
+        else:
+            print '\nUpload complete'
 
     def _connect(self):
         """Connects client attribute to service"""
@@ -228,7 +283,8 @@ class SSHUploader(BaseUploader):
         self.ssh.load_system_host_keys()
         self.ssh.connect(self.host, username=self.username,
                          key_filename=self.ssh_key_file)
-        self.client = SCPClient(self.ssh.get_transport())
+        self.client = SCPClient(self.ssh.get_transport(),
+                                progress=ssh_progress)
 
     def _upload_file(self, filename):
         with ChDir(self.deploy_dir):
@@ -241,6 +297,12 @@ class SSHUploader(BaseUploader):
                 return False
 
 
+def ssh_progress(filename, size, sent):
+    percent = float(sent) / size * 100
+    sys.stdout.write('\r%.1f' % percent)
+    sys.stdout.flush()
+
+
 # TODO: figure out how to upload files
 # deeper then just the root directory
 class S3Uploader(BaseUploader):
@@ -252,11 +314,13 @@ class S3Uploader(BaseUploader):
         self.secret_key = kwargs['aws_secret_key']
         self.bucket_name = kwargs['bucket_name']
         self.deploy_dir = None
+        self._connect()
 
     def _connect(self):
         """Connects client attribute to S3"""
         self.s3 = S3Connection(aws_access_key_id=self.access_key,
-                               aws_secert_access_key=self.secret_key)
+                               aws_secret_access_key=self.secret_key,
+                               debug=True)
         bucket = self.s3.get_bucket(self.bucket_name)
         self.client = Key(bucket)
 
@@ -276,16 +340,24 @@ class S3Uploader(BaseUploader):
         with ChDir(self.deploy_dir):
             self.client.key = filename
             try:
-                self.client.set_contents_from_file(filename)
+                self.client.set_contents_from_filename(filename,
+                                                   cb=s3_progress)
                 self.client.make_public()
                 print 'Did that upload boy'
                 return True
-            except:
+            except S3ResponseError as e:
+                log.error(str(e), exc_info=True)
                 self._connect()
                 print 'Oopss didn\'t upload that boy'
                 return False
 
 
+def s3_progress(current, total):
+    percent = float(current) / total * 100
+    sys.stdout.write('\r%.1f' % percent)
+    sys.stdout.flush()
+
+
 class SFTPUploader(BaseUploader):
 
     def __init__(self, *args, **kwargs):
@@ -295,7 +367,7 @@ class SFTPUploader(BaseUploader):
         sftp_uploader = FTP_TLS(self.host, user='', passwd='')
         sftp_uploader.login()
         sftp_uploader.prot_p()
-        return ftp_uploader
+        return sftp_uploader
 
     def _connect(self):
         self.client = self._reconnect()
