@@ -1,3 +1,25 @@
+# The MIT License (MIT)
+#
+# Copyright (c) 2014 JohnyMoSwag <johnymoswag@gmail.com>
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
+
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
+
 import base64
 import getpass
 import hashlib
@@ -7,9 +29,15 @@ import platform
 import struct
 import sys
 
-import beefish
-import keyring
-import pbkdf2
+from not_so_tuf import NotSoTufError
+
+try:
+    import beefish
+    import keyring
+    import pbkdf2
+except ImportError:
+    raise NotSoTufError('Must have beefish, keyring & pbkdf2 installed.',
+                        expected=True)
 
 log = logging.getLogger(__name__)
 
@@ -18,7 +46,7 @@ if getattr(sys, 'frozen', False):
     # we are running in a |PyInstaller| bundle
     _cwd = os.path.dirname(sys.argv[0])
 else:
-    log.debug('Running thawed out')
+    log.debug('Running thawed out.  e.g. not frozen :)')
     # we are running in a normal Python environment
     _cwd = os.getcwd()
 
@@ -60,7 +88,7 @@ class FileCrypt(object):
             os.remove(self.filename)
         except IOError:
             log.warning('Cannot find original file')
-        self._del_password()
+        self._del_internal_password()
 
     def decrypt(self):
         """Decrypts encrypted file. Leaves encrypted file in case user
@@ -74,7 +102,7 @@ class FileCrypt(object):
         except IOError:
             log.warning('Cannot find encrypted file.')
 
-    def _del_password(self):
+    def _del_internal_password(self):
         """Deletes user password once its not needed.
         i.e. when the file been encrypted.
         """
@@ -121,6 +149,16 @@ class FileCrypt(object):
         hashed = pbkdf2.crypt(password1)
         keyring.set_password(app_name, username, hashed)
 
+    def _del_password(self):
+        username = self.make_username()
+        app_name = 'NST-' + username
+        self._get_password()
+        if self.password:
+            del self.self.password
+            keyring.delete_password(app_name, username)
+        else:
+            pass
+
     def make_username(self):
         """Makes username by base54 encoding current working directory.
         """
@@ -255,8 +293,10 @@ def _remove_hidden_stuff_mac(files):
                 new_list.append(l)
         return new_list
 
+
 def _version_string_to_tuple(version):
         return tuple(map(int, version.split('.')))
 
+
 def _version_tuple_to_string(version):
     return '.'.join(map(str, version))
